==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/app/controllers/resign_controller.rb <==
class ResignController < ApplicationController

  def index
    session[:resigned_reason] = nil
    redirect_to :action => :enter_reason
  end

  #
  # 退会理由入力画面
  #
  def enter_reason
    # バリデーションエラーで戻った場合
    if flash[:resigned_reason]
      @resigned_reason = flash[:resigned_reason]
      render :template => 'resigned_reason/resigned_reason'
      return
    end
    # 戻るボタンで戻った場合
    if session[:resigned_reason]
      @resigned_reason = session[:resigned_reason]
    # 初期表示
    else
      @resigned_reason = ResignedReason.new(:ms_resigned_reason_id => '1')
    end

    render :template => 'resigned_reason/resigned_reason'
  end

  #
  # 退会理由入力確認
  #
  def confirm
    return redirect_to_root unless logged_in?
    return redirect_to(:action => 'enter_reason') unless params[:resigned_reason]

    #退会情報生成
    resigned_reason = ResignedReason.new(params[:resigned_reason])

    unless resigned_reason.valid?
      flash[:resigned_reason] = resigned_reason
      redirect_back_or_default :action => :enter_reason
      return
    end

    @resigned_reason = resigned_reason
    session[:resigned_reason] = resigned_reason

    render :template => 'resigned_reason/confirm'
  end

  #
  # 退会
  #
  def update_information
    return redirect_to_root unless logged_in?
    return redirect_to(:action => 'enter_reason') unless session[:resigned_reason]

    #ログイン情報から、退会完了メール送信に必要な情報を取得しておく
    last_name = current_user.name_last
    first_name = current_user.name_first
    user_name = current_user.fullname
    email = current_user.user_email.email
    user_id = current_user.id

    #退会処理
    current_user.resigned(session[:resigned_reason])
    current_user.forget_me if logged_in?

    # 退会完了メール送信
    FrontSiteMailer.send_resign_mail(user_id, last_name, first_name, user_name, email)

    # ログアウトとセッションクリア
    cookies.delete :auth_token
    session[:resigned_reason] = nil
    session[:user] = nil
    reset_session

    redirect_to :action => :completion
  end

  #
  # 退会完了
  #
  def completion
    render :template => 'resigned_reason/completion'
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/app/controllers/resign_controller.rb <==
class ResignController < ApplicationController
  include EcRider::SetDefaultLayout

  def index
    session[:resigned_reason] = nil
    redirect_to :action => :enter_reason
  end

  #
  # 退会理由入力画面
  #
  def enter_reason
    # バリデーションエラーで戻った場合
    if flash[:resigned_reason]
      @resigned_reason = flash[:resigned_reason]
      render :template => 'resigned_reason/resigned_reason'
      return
    end
    # 戻るボタンで戻った場合
    if session[:resigned_reason]
      @resigned_reason = session[:resigned_reason]
    # 初期表示
    else
      @resigned_reason = ResignedReason.new(:ms_resigned_reason_id => '1')
    end

    render :template => 'resigned_reason/resigned_reason'
  end

  #
  # 退会理由入力確認
  #
  def confirm
    return redirect_to_root unless logged_in?
    return redirect_to(:action => 'enter_reason') unless params[:resigned_reason]

    #退会情報生成
    resigned_reason = ResignedReason.new(params[:resigned_reason])

    unless resigned_reason.valid?
      flash[:resigned_reason] = resigned_reason
      redirect_back_or_default :action => :enter_reason
      return
    end

    @resigned_reason = resigned_reason
    session[:resigned_reason] = resigned_reason

    render :template => 'resigned_reason/confirm'
  end

  #
  # 退会
  #
  def update_information
    return redirect_to_root unless logged_in?
    return redirect_to(:action => 'enter_reason') unless session[:resigned_reason]

    #ログイン情報から、退会完了メール送信に必要な情報を取得しておく
    last_name = current_user.name_last
    first_name = current_user.name_first
    user_name = current_user.fullname

    user_id = current_user.id

    #退会処理
    current_user.resigned(session[:resigned_reason])
    current_user.forget_me if logged_in?

    # 退会完了メール送信
    # PCサイト用、モバイルサイト用共にメールを送信する
    current_user.user_emails.each do |user_email|
      FrontSiteMailer.send_resign_mail(user_id, last_name, first_name, user_name, user_email.email)
    end

    # ログアウトとセッションクリア
    cookies.delete :auth_token
    session[:resigned_reason] = nil
    session[:user] = nil
    reset_session

    redirect_to :action => :completion
  end

  #
  # 退会完了
  #
  def completion
    render :template => 'resigned_reason/completion'
  end
end
